@@ -2,7 +2,11 @@
 import click
 
 from gencove.command.common_cli_options import add_options, common_options
-from gencove.constants import Credentials, SAMPLE_STATUS
+from gencove.constants import (
+    Credentials,
+    SAMPLE_ARCHIVE_STATUS,
+    SAMPLE_STATUS,
+)
 
 from .constants import SamplesOptions
 from .main import ListSamples
@@ -19,13 +23,19 @@ from .main import ListSamples
     type=click.Choice(SAMPLE_STATUS._asdict().values()),
     default=SAMPLE_STATUS.all,
 )
+@click.option(
+    "--archive-status",
+    help="Get samples with specific archive status",
+    type=click.Choice(SAMPLE_ARCHIVE_STATUS._asdict().values()),
+    default=SAMPLE_ARCHIVE_STATUS.all,
+)
 @add_options(common_options)
 def list_project_samples(  # pylint: disable=E0012,C0330,R0913
-    project_id, search, status, host, email, password, api_key
+    project_id, search, status, archive_status, host, email, password, api_key
 ):
     """List samples in a project."""
     ListSamples(
         project_id,
         Credentials(email, password, api_key),
-        SamplesOptions(host, status, search),
+        SamplesOptions(host, status, archive_status, search),
     ).run()
