@@ -77,76 +77,11 @@ def test_project_id_provided(mocker):
                     "status": "succeeded",
                     "created": "2020-07-28T12:46:22.719862Z",
                 },
-                "files": [
-                    {
-                        "id": str(uuid4()),
-                        "file_type": "txt",
-                        "download_url": "https://foo.com/bar.txt",
-                    }
-                ],
-            },
-        )
-        mocked_qc_metrics = mocker.patch.object(
-            APIClient,
-            "get_sample_qc_metrics",
-            return_value={"results": [{"foo": 12}]},
-        )
-        mocked_get_metadata = mocker.patch.object(
-            APIClient,
-            "get_metadata",
-            return_value=dict(
-                metadata=None,
-            ),
-        )
-        mocked_download_file = mocker.patch(
-            "gencove.command.download.main.download_file"
-        )
-        mocked_save_qc_metrics = mocker.patch(
-            "gencove.command.download.main.save_qc_file"
-        )
-        mocked_save_metadata = mocker.patch(
-            "gencove.command.download.main.save_metadata_file"
-        )
-        res = runner.invoke(
-            download,
-            [
-                "cli_test_data",
-                "--project-id",
-                "123",
-                "--email",
-                "foo@bar.com",
-                "--password",
-                "123",
-            ],
-        )
-        assert res.exit_code == 0
-        mocked_login.assert_called_once()
-        mocked_project_samples.assert_called_once()
-        mocked_qc_metrics.assert_called_once()
-        mocked_get_metadata.assert_called_once()
-        mocked_download_file.assert_called_once()
-        mocked_save_qc_metrics.assert_called_once()
-        mocked_save_metadata.assert_called_once()
-        mocked_sample_details.assert_called_once()
-
-
-def test_sample_ids_provided(mocker):
-    """Check happy flow with sample ids."""
-    runner = CliRunner()
-    with runner.isolated_filesystem():
-        mocked_login = mocker.patch.object(
-            APIClient, "login", return_value=None
-        )
-        mocked_sample_details = mocker.patch.object(
-            APIClient,
-            "get_sample_details",
-            return_value={
-                "id": 0,
-                "client_id": 1,
-                "last_status": {
+                "archive_last_status": {
                     "id": str(uuid4()),
-                    "status": "succeeded",
+                    "status": "available",
                     "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
                 },
                 "files": [
                     {
@@ -172,11 +107,74 @@ def test_sample_ids_provided(mocker):
         mocked_download_file = mocker.patch(
             "gencove.command.download.main.download_file"
         )
-        mocked_save_qc_metrics = mocker.patch(
-            "gencove.command.download.main.save_qc_file"
+        res = runner.invoke(
+            download,
+            [
+                "cli_test_data",
+                "--project-id",
+                "123",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+            ],
         )
-        mocked_save_metadata = mocker.patch(
-            "gencove.command.download.main.save_metadata_file"
+        assert res.exit_code == 0
+        mocked_login.assert_called_once()
+        mocked_project_samples.assert_called_once()
+        mocked_qc_metrics.assert_called_once()
+        mocked_get_metadata.assert_called_once()
+        mocked_download_file.assert_called_once()
+        mocked_sample_details.assert_called_once()
+
+
+def test_sample_ids_provided(mocker):
+    """Check happy flow with sample ids."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_sample_details = mocker.patch.object(
+            APIClient,
+            "get_sample_details",
+            return_value={
+                "id": 0,
+                "client_id": 1,
+                "last_status": {
+                    "id": str(uuid4()),
+                    "status": "succeeded",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
+                "files": [
+                    {
+                        "id": str(uuid4()),
+                        "file_type": "txt",
+                        "download_url": "https://foo.com/bar.txt",
+                    }
+                ],
+            },
+        )
+        mocked_qc_metrics = mocker.patch.object(
+            APIClient,
+            "get_sample_qc_metrics",
+            return_value={"results": [{"foo": 12}]},
+        )
+        mocked_get_metadata = mocker.patch.object(
+            APIClient,
+            "get_metadata",
+            return_value=dict(
+                metadata=None,
+            ),
+        )
+        mocked_download_file = mocker.patch(
+            "gencove.command.download.main.download_file"
         )
         res = runner.invoke(
             download,
@@ -201,8 +199,6 @@ def test_sample_ids_provided(mocker):
         mocked_sample_details.assert_called_once()
         mocked_qc_metrics.assert_called_once()
         mocked_get_metadata.assert_called_once()
-        mocked_save_qc_metrics.assert_called_once()
-        mocked_save_metadata.assert_called_once()
 
 
 def test_sample_ids_provided_no_qc_file(mocker):
@@ -223,6 +219,12 @@ def test_sample_ids_provided_no_qc_file(mocker):
                     "status": "succeeded",
                     "created": "2020-07-28T12:46:22.719862Z",
                 },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
                 "files": [],
             },
         )
@@ -231,20 +233,11 @@ def test_sample_ids_provided_no_qc_file(mocker):
             "get_sample_qc_metrics",
             return_value={"results": [{"foo": 12}]},
         )
-        mocked_save_qc_metrics = mocker.patch(
-            "gencove.command.download.main.save_qc_file"
-        )
-        mocked_validate_and_download = mocker.patch(
-            "gencove.command.download.main.Download.validate_and_download"
-        )
         mocked_get_metadata = mocker.patch.object(
             APIClient,
             "get_metadata",
             return_value={"metadata": [{"foo": 12}]},
         )
-        mocked_save_metadata = mocker.patch(
-            "gencove.command.download.main.save_metadata_file"
-        )
         res = runner.invoke(
             download,
             [
@@ -258,15 +251,10 @@ def test_sample_ids_provided_no_qc_file(mocker):
             ],
         )
         assert res.exit_code == 0
-        file_path = "cli_test_data/1/0/0_qc.json"
-        mocked_validate_and_download.assert_any_call(
-            file_path, mocked_save_qc_metrics, file_path, [{"foo": 12}]
-        )
         mocked_login.assert_called_once()
         mocked_sample_details.assert_called_once()
         mocked_qc_metrics.assert_called_once()
         mocked_get_metadata.assert_called_once()
-        mocked_save_metadata.assert_not_called()
 
 
 def test_sample_ids_provided_no_metadata_file(mocker):
@@ -287,6 +275,12 @@ def test_sample_ids_provided_no_metadata_file(mocker):
                     "status": "succeeded",
                     "created": "2020-07-28T12:46:22.719862Z",
                 },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
                 "files": [],
             },
         )
@@ -295,20 +289,11 @@ def test_sample_ids_provided_no_metadata_file(mocker):
             "get_metadata",
             return_value={"metadata": [{"foo": 12}]},
         )
-        mocked_save_metadata = mocker.patch(
-            "gencove.command.download.main.save_metadata_file"
-        )
         mocked_qc_metrics = mocker.patch.object(
             APIClient,
             "get_sample_qc_metrics",
             return_value={"results": [{"foo": 12}]},
         )
-        mocked_save_qc_metrics = mocker.patch(
-            "gencove.command.download.main.save_qc_file"
-        )
-        mocked_validate_and_download = mocker.patch(
-            "gencove.command.download.main.Download.validate_and_download"
-        )
         res = runner.invoke(
             download,
             [
@@ -322,18 +307,10 @@ def test_sample_ids_provided_no_metadata_file(mocker):
             ],
         )
         assert res.exit_code == 0
-        file_path = "cli_test_data/1/0/0_metadata.json"
-        mocked_validate_and_download.assert_called_with(
-            file_path,
-            mocked_save_metadata,
-            file_path,
-            {"metadata": [{"foo": 12}]},
-        )
         mocked_login.assert_called_once()
         mocked_sample_details.assert_called_once()
         mocked_get_metadata.assert_called_once()
         mocked_qc_metrics.assert_called_once()
-        mocked_save_qc_metrics.assert_not_called()
 
 
 def test_multiple_credentials_not_allowed():
@@ -397,6 +374,7 @@ def test_download_stdout_with_flag(mocker):
         return_value={"results": [{"id": 0}], "meta": {"next": None}},
     )
     last_status_id = str(uuid4())
+    archive_last_status_id = str(uuid4())
     file_id = str(uuid4())
     mocked_sample_details = mocker.patch.object(
         APIClient,
@@ -409,6 +387,12 @@ def test_download_stdout_with_flag(mocker):
                 "status": "succeeded",
                 "created": "2020-07-28T12:46:22.719862Z",
             },
+            "archive_last_status": {
+                "id": archive_last_status_id,
+                "status": "available",
+                "created": "2020-07-28T12:46:22.719862Z",
+                "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+            },
             "files": [
                 {
                     "id": file_id,
@@ -447,6 +431,12 @@ def test_download_stdout_with_flag(mocker):
                     "status": "succeeded",
                     "created": "2020-07-28T12:46:22.719862Z",
                 },
+                "archive_last_status": {
+                    "id": archive_last_status_id,
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
                 "files": {
                     "txt": {
                         "id": file_id,
@@ -471,6 +461,7 @@ def test_download_urls_to_file(mocker):
         return_value={"results": [{"id": 0}], "meta": {"next": None}},
     )
     last_status_id = str(uuid4())
+    archive_last_status_id = str(uuid4())
     file_id = str(uuid4())
     mocked_sample_details = mocker.patch.object(
         APIClient,
@@ -483,6 +474,12 @@ def test_download_urls_to_file(mocker):
                 "status": "succeeded",
                 "created": "2020-07-28T12:46:22.719862Z",
             },
+            "archive_last_status": {
+                "id": archive_last_status_id,
+                "status": "available",
+                "created": "2020-07-28T12:46:22.719862Z",
+                "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+            },
             "files": [
                 {
                     "id": file_id,
@@ -534,6 +531,12 @@ def test_download_no_progress(mocker):
                     "status": "succeeded",
                     "created": "2020-07-28T12:46:22.719862Z",
                 },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
                 "files": [
                     {
                         "id": str(uuid4()),
@@ -558,12 +561,6 @@ def test_download_no_progress(mocker):
         mocked_download_file = mocker.patch(
             "gencove.command.download.main.download_file"
         )
-        mocked_save_qc_metrics = mocker.patch(
-            "gencove.command.download.main.save_qc_file"
-        )
-        mocked_save_metadata = mocker.patch(
-            "gencove.command.download.main.save_metadata_file"
-        )
         res = runner.invoke(
             download,
             [
@@ -585,5 +582,250 @@ def test_download_no_progress(mocker):
         mocked_sample_details.assert_called_once()
         mocked_qc_metrics.assert_called_once()
         mocked_get_metadata.assert_called_once()
-        mocked_save_qc_metrics.assert_called_once()
-        mocked_save_metadata.assert_called_once()
+
+
+def test_project_id_provided_skip_existing_qc_and_metadata(mocker):
+    """Check happy flow."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_project_samples = mocker.patch.object(
+            APIClient,
+            "get_project_samples",
+            return_value={"results": [{"id": 0}], "meta": {"next": None}},
+        )
+        mocked_sample_details = mocker.patch.object(
+            APIClient,
+            "get_sample_details",
+            return_value={
+                "id": 0,
+                "client_id": 1,
+                "last_status": {
+                    "id": str(uuid4()),
+                    "status": "succeeded",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "available",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
+                "files": [
+                    {
+                        "id": str(uuid4()),
+                        "file_type": "txt",
+                        "download_url": "https://foo.com/bar.txt",
+                    }
+                ],
+            },
+        )
+        mocked_qc_metrics = mocker.patch.object(
+            APIClient,
+            "get_sample_qc_metrics",
+            return_value={"results": [{"foo": 12}]},
+        )
+        mocked_get_metadata = mocker.patch.object(
+            APIClient,
+            "get_metadata",
+            return_value=dict(
+                metadata=None,
+            ),
+        )
+        mocked_download_file = mocker.patch(
+            "gencove.command.download.main.download_file"
+        )
+        res = runner.invoke(
+            download,
+            [
+                "cli_test_data",
+                "--project-id",
+                "123",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+                "--no-skip-existing",
+            ],
+        )
+        assert res.exit_code == 0
+        mocked_login.assert_called_once()
+        mocked_project_samples.assert_called_once()
+        mocked_qc_metrics.assert_called_once()
+        mocked_get_metadata.assert_called_once()
+        mocked_download_file.assert_called_once()
+        mocked_sample_details.assert_called_once()
+
+        # call it the second time
+        mocked_qc_metrics = mocker.patch.object(
+            APIClient,
+            "get_sample_qc_metrics",
+            return_value={"results": [{"foo": 12}]},
+        )
+        mocked_get_metadata = mocker.patch.object(
+            APIClient,
+            "get_metadata",
+            return_value=dict(
+                metadata=None,
+            ),
+        )
+        res = runner.invoke(
+            download,
+            [
+                "cli_test_data",
+                "--project-id",
+                "123",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+                "--skip-existing",
+            ],
+        )
+        assert res.exit_code == 0
+        mocked_qc_metrics.assert_not_called()
+        mocked_get_metadata.assert_not_called()
+
+
+def test_download_not_working_because_archived(mocker):
+    """Test command doesn't download archived files."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_sample_details = mocker.patch.object(
+            APIClient,
+            "get_sample_details",
+            return_value={
+                "id": 0,
+                "client_id": 1,
+                "last_status": {
+                    "id": str(uuid4()),
+                    "status": "succeeded",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "archived",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
+                "files": [
+                    {
+                        "id": str(uuid4()),
+                        "file_type": "txt",
+                        "download_url": None,
+                    }
+                ],
+            },
+        )
+        mocked_qc_metrics = mocker.patch.object(
+            APIClient,
+            "get_sample_qc_metrics",
+            return_value={"results": [{"foo": 12}]},
+        )
+        mocked_get_metadata = mocker.patch.object(
+            APIClient,
+            "get_metadata",
+            return_value=dict(
+                metadata=None,
+            ),
+        )
+        mocked_download_file = mocker.patch(
+            "gencove.command.download.main.download_file"
+        )
+        res = runner.invoke(
+            download,
+            [
+                "cli_test_data",
+                "--sample-ids",
+                "0",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+            ],
+        )
+        assert res.exit_code == 1
+        mocked_login.assert_called_once()
+        mocked_download_file.assert_not_called()
+        mocked_sample_details.assert_called_once()
+        mocked_qc_metrics.assert_not_called()
+        mocked_get_metadata.assert_not_called()
+
+
+def test_project_id_provided_filter_not_archived(mocker):
+    """Check happy flow."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_project_samples = mocker.patch.object(
+            APIClient,
+            "get_project_samples",
+            return_value={"results": [], "meta": {"next": None}},
+        )
+        mocked_sample_details = mocker.patch.object(
+            APIClient,
+            "get_sample_details",
+            return_value={
+                "id": 0,
+                "client_id": 1,
+                "last_status": {
+                    "id": str(uuid4()),
+                    "status": "succeeded",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                },
+                "archive_last_status": {
+                    "id": str(uuid4()),
+                    "status": "archived",
+                    "created": "2020-07-28T12:46:22.719862Z",
+                    "transition_cutoff": "2020-08-28T12:46:22.719862Z",
+                },
+                "files": [
+                    {
+                        "id": str(uuid4()),
+                        "file_type": "txt",
+                        "download_url": None,
+                    }
+                ],
+            },
+        )
+        mocked_qc_metrics = mocker.patch.object(
+            APIClient,
+            "get_sample_qc_metrics",
+            return_value={"results": [{"foo": 12}]},
+        )
+        mocked_get_metadata = mocker.patch.object(
+            APIClient,
+            "get_metadata",
+            return_value=dict(
+                metadata=None,
+            ),
+        )
+        mocked_download_file = mocker.patch(
+            "gencove.command.download.main.download_file"
+        )
+        res = runner.invoke(
+            download,
+            [
+                "cli_test_data",
+                "--project-id",
+                "123",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+            ],
+        )
+        assert res.exit_code == 1
+        mocked_login.assert_called_once()
+        mocked_project_samples.assert_called_once()
+        mocked_qc_metrics.assert_not_called()
+        mocked_get_metadata.assert_not_called()
+        mocked_download_file.assert_not_called()
+        mocked_sample_details.assert_not_called()
