@@ -43,8 +43,6 @@ def test_upload(mocker):
             ["cli_test_data"],
             input="\n".join(["foo@bar.com", "123456"]),
         )
-        # for debugging, if needed
-        print("output is", res.output)
 
         assert res.exit_code == 0
         mocked_login.assert_called_once()
@@ -68,8 +66,6 @@ def test_upload_no_files_found(mocker):
             ["cli_test_data"],
             input="\n".join(["foo@bar.com", "123456"]),
         )
-        # for debugging, if needed
-        print("output is", res.output)
 
         assert res.exit_code == 1
         assert "No FASTQ files found in the path" in res.output
@@ -92,8 +88,6 @@ def test_upload_invalid_destination(mocker):
             ["cli_test_data", "foobar_dir"],
             input="\n".join(["foo@bar.com", "123456"]),
         )
-        # for debugging, if needed
-        print("output is", res.output)
 
         assert res.exit_code == 1
         assert (
@@ -105,6 +99,36 @@ def test_upload_invalid_destination(mocker):
         mocked_login.assert_called_once()
 
 
+def test_upload_project_id_not_uuid(mocker):
+    """Test that project id is valid UUID when uploading."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        os.mkdir("cli_test_data")
+        with open("cli_test_data/test.fastq.gz", "w") as fastq_file:
+            fastq_file.write("AAABBB")
+
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+
+        res = runner.invoke(
+            upload,
+            [
+                "cli_test_data",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123456",
+                "--run-project-id",
+                "1234",
+            ],
+        )
+
+        assert res.exit_code == 1
+        assert "--run-project-id is not valid" in res.output
+        mocked_login.assert_called_once()
+
+
 def test_upload_and_run_immediately(mocker):
     """Upload and assign right away."""
     runner = CliRunner()
@@ -157,7 +181,7 @@ def test_upload_and_run_immediately(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
             ],
         )
 
@@ -171,6 +195,172 @@ def test_upload_and_run_immediately(mocker):
         mocked_regular_progress_bar.assert_called_once()
 
 
+def test_upload_and_run_immediately__with_metadata(mocker):
+    """Upload and assign right away."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        os.mkdir("cli_test_data")
+        with open("cli_test_data/test.fastq.gz", "w") as fastq_file:
+            fastq_file.write("AAABBB")
+
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_get_credentials = mocker.patch(
+            "gencove.command.upload.main.get_s3_client_refreshable"
+        )
+        mocked_get_upload_details = mocker.patch.object(
+            APIClient,
+            "get_upload_details",
+            return_value={
+                "id": "test",
+                "last_status": {"status": ""},
+                "s3": {"bucket": "test", "object_name": "test"},
+            },
+        )
+        mocked_upload_file = mocker.patch(
+            "gencove.command.upload.main.upload_file"
+        )
+        mocked_get_sample_sheet = mocker.patch.object(
+            APIClient,
+            "get_sample_sheet",
+            return_value={
+                "meta": {"next": None},
+                "results": [
+                    {"client_id": "foo", "fastq": {"r1": {"upload": "test"}}}
+                ],
+            },
+        )
+        mocked_assign_sample = mocker.patch.object(
+            APIClient, "add_samples_to_project", return_value={}
+        )
+        mocked_regular_progress_bar = mocker.patch(
+            "gencove.command.upload.main.get_regular_progress_bar"
+        )
+
+        res = runner.invoke(
+            upload,
+            [
+                "cli_test_data",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123456",
+                "--run-project-id",
+                "11111111-1111-1111-1111-111111111111",
+                "--metadata",
+                "[1,2]",
+            ],
+        )
+
+        assert res.exit_code == 0
+        mocked_login.assert_called_once()
+        mocked_get_credentials.assert_called_once()
+        mocked_get_upload_details.assert_called_once()
+        mocked_upload_file.assert_called_once()
+        mocked_get_sample_sheet.assert_called()
+        mocked_assign_sample.assert_called_once()
+        mocked_regular_progress_bar.assert_called_once()
+
+
+def test_upload_and_run_immediately__invalid_metadata(mocker):
+    """Upload and assign right away with invalid metadata."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        os.mkdir("cli_test_data")
+        with open("cli_test_data/test.fastq.gz", "w") as fastq_file:
+            fastq_file.write("AAABBB")
+
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+        mocked_get_credentials = mocker.patch(
+            "gencove.command.upload.main.get_s3_client_refreshable"
+        )
+        mocked_get_upload_details = mocker.patch.object(
+            APIClient,
+            "get_upload_details",
+            return_value={
+                "id": "test",
+                "last_status": {"status": ""},
+                "s3": {"bucket": "test", "object_name": "test"},
+            },
+        )
+        mocked_upload_file = mocker.patch(
+            "gencove.command.upload.main.upload_file"
+        )
+        mocked_get_sample_sheet = mocker.patch.object(
+            APIClient,
+            "get_sample_sheet",
+            return_value={
+                "meta": {"next": None},
+                "results": [
+                    {"client_id": "foo", "fastq": {"r1": {"upload": "test"}}}
+                ],
+            },
+        )
+        mocked_assign_sample = mocker.patch.object(
+            APIClient, "add_samples_to_project", return_value={}
+        )
+
+        res = runner.invoke(
+            upload,
+            [
+                "cli_test_data",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123456",
+                "--run-project-id",
+                "11111111-1111-1111-1111-111111111111",
+                "--metadata",
+                "[1,2,3",
+            ],
+        )
+
+        assert res.exit_code == 1
+        mocked_login.assert_called_once()
+        mocked_get_credentials.assert_not_called()
+        mocked_get_upload_details.assert_not_called()
+        mocked_upload_file.assert_not_called()
+        mocked_get_sample_sheet.assert_not_called()
+        mocked_assign_sample.assert_not_called()
+        assert "--metadata is not valid JSON" in res.output
+
+
+def test_upload__with_metadata_without_project_id(mocker):
+    """Test that project id is present if attaching metadata when
+    uploading."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        os.mkdir("cli_test_data")
+        with open("cli_test_data/test.fastq.gz", "w") as fastq_file:
+            fastq_file.write("AAABBB")
+
+        mocked_login = mocker.patch.object(
+            APIClient, "login", return_value=None
+        )
+
+        res = runner.invoke(
+            upload,
+            [
+                "cli_test_data",
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123456",
+                "--metadata",
+                "[1,2]",
+            ],
+        )
+
+        assert res.exit_code == 1
+        assert (
+            "--metadata cannot be used without --run-project-id" in res.output
+        )
+        mocked_login.assert_called_once()
+
+
 def test_upload_and_run_immediately_something_went_wrong(mocker):
     """Upload and assign right away did't work."""
     runner = CliRunner()
@@ -215,7 +405,7 @@ def test_upload_and_run_immediately_something_went_wrong(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
             ],
         )
 
@@ -287,7 +477,7 @@ def test_upload_and_run_immediately_with_output_to_file(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
                 "--output",
                 "samples.json",
             ],
@@ -365,7 +555,7 @@ def test_upload_and_run_immediately_with_output_to_nested_file(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
                 "--output",
                 "somefolder/samples.json",
             ],
@@ -443,7 +633,7 @@ def test_upload_and_run_immediately_with_stdout(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
                 "--output",
                 "-",
             ],
@@ -561,7 +751,7 @@ def test_upload_and_run_immediately_without_progressbar(mocker):
                 "--password",
                 "123456",
                 "--run-project-id",
-                "1234",
+                "11111111-1111-1111-1111-111111111111",
                 "--no-progress",
             ],
         )
